### Reference

To allow data ingestion into the unified `zampy` format and to enable variables conversion between different conventions, we need a unique identifier for each variable. Therefore we create a `variables.py` file to store the `zampy` unique variable names for reference.

### Ingestion

During data ingestion, all variables will be formatted to `zampy` variable format.

 